@@ -61,6 +61,7 @@ type HelmRelease struct {
 	Name      string `json:"name"`
 	Namespace string `json:"namespace"`
 	Enabled   bool   `json:"enabled"`
+	Installed bool   `json:"installed"`
 	Labels    string `json:"labels"`
 	Chart     string `json:"chart"`
 	Version   string `json:"version"`
@@ -257,6 +258,7 @@ func (a *App) WriteValues(c WriteValuesConfigProvider) error {
 			ForceDownload: !run.helm.IsHelm3(),
 			SkipRepos:     c.SkipDeps(),
 			SkipDeps:      c.SkipDeps(),
+			SkipCleanup:   c.SkipCleanup(),
 		}, func() {
 			ok, errs = a.writeValues(run, c)
 		})
@@ -306,6 +308,7 @@ func (a *App) Lint(c LintConfigProvider) error {
 			ForceDownload: true,
 			SkipRepos:     c.SkipDeps(),
 			SkipDeps:      c.SkipDeps(),
+			SkipCleanup:   c.SkipCleanup(),
 		}, func() {
 			ok, lintErrs, errs = a.lint(run, c)
 		})
@@ -575,11 +578,17 @@ func (a *App) ListReleases(c ListConfigProvider) error {
 				}
 				labels = strings.Trim(labels, ",")
 
+				enabled, err := state.ConditionEnabled(r, run.state.Values())
+				if err != nil {
+					panic(err)
+				}
+
 				installed := r.Installed == nil || *r.Installed
 				releases = append(releases, &HelmRelease{
 					Name:      r.Name,
 					Namespace: r.Namespace,
-					Enabled:   installed,
+					Installed: installed,
+					Enabled:   enabled,
 					Labels:    labels,
 					Chart:     r.Chart,
 					Version:   r.Version,
@@ -1149,29 +1158,61 @@ func (a *App) getSelectedReleases(r *Run, includeTransitiveNeeds bool) ([]state.
 		return nil, nil, err
 	}
 
-	selectedIds := map[string]struct{}{}
+	selectedIds := map[string]state.ReleaseSpec{}
+	selectedCounts := map[string]int{}
 	for _, r := range selected {
-		selectedIds[state.ReleaseToID(&r)] = struct{}{}
+		r := r
+		id := state.ReleaseToID(&r)
+		selectedIds[id] = r
+		selectedCounts[id]++
+
+		if dupCount := selectedCounts[id]; dupCount > 1 {
+			return nil, nil, fmt.Errorf("found %d duplicate releases with ID %q", dupCount, id)
+		}
 	}
 
 	allReleases := r.state.GetReleasesWithOverrides()
 
-	needed := map[string]struct{}{}
-	for _, r := range selected {
-		collectNeeds(r, selectedIds, needed, allReleases, includeTransitiveNeeds)
-	}
-
-	var releases []state.ReleaseSpec
-
-	releases = append(releases, selected...)
-
+	groupsByID := map[string][]*state.ReleaseSpec{}
 	for _, r := range allReleases {
-		if _, ok := needed[state.ReleaseToID(&r)]; ok {
-			releases = append(releases, r)
-		}
+		r := r
+		groupsByID[state.ReleaseToID(&r)] = append(groupsByID[state.ReleaseToID(&r)], &r)
 	}
 
-	if err := checkDuplicates(r.helm, r.state, releases); err != nil {
+	var deduplicated []state.ReleaseSpec
+
+	dedupedBefore := map[string]struct{}{}
+
+	// We iterate over allReleases rather than groupsByID
+	// to preserve the order of releases
+	for _, seq := range allReleases {
+		id := state.ReleaseToID(&seq)
+
+		rs := groupsByID[id]
+
+		if len(rs) == 1 {
+			deduplicated = append(deduplicated, *rs[0])
+			continue
+		}
+
+		if _, ok := dedupedBefore[id]; ok {
+			continue
+		}
+
+		// We keep the selected one only when there were two or more duplicate
+		// releases in the helmfile config.
+		// Otherwise we can't compute the DAG of releases correctly.
+		r, deduped := selectedIds[id]
+		if !deduped {
+			panic(fmt.Errorf("assertion error: release %q has never been selected. This shouldn't happen!", id))
+		}
+
+		deduplicated = append(deduplicated, r)
+
+		dedupedBefore[id] = struct{}{}
+	}
+
+	if err := checkDuplicates(r.helm, r.state, deduplicated); err != nil {
 		return nil, nil, err
 	}
 
@@ -1183,42 +1224,7 @@ func (a *App) getSelectedReleases(r *Run, includeTransitiveNeeds bool) ([]state.
 
 	a.Logger.Debugf("%d release(s)%s found in %s\n", len(selected), extra, r.state.FilePath)
 
-	return selected, releases, nil
-}
-
-func collectNeeds(release state.ReleaseSpec, selectedIds map[string]struct{}, needed map[string]struct{}, allReleases []state.ReleaseSpec, includeTransitiveNeeds bool) {
-	for _, id := range release.Needs {
-		// Avoids duplicating a release that is selected AND also needed by another selected release
-		if _, ok := selectedIds[id]; !ok {
-			if _, ok := needed[id]; !ok {
-				needed[id] = struct{}{}
-				if includeTransitiveNeeds {
-					releaseParts := strings.Split(id, "/")
-					releasePartsCount := len(releaseParts)
-					releaseName := releaseParts[releasePartsCount-1]
-					releaseNamespace := ""
-					releaseKubeContext := ""
-					if releasePartsCount > 1 {
-						releaseNamespace = releaseParts[releasePartsCount-2]
-					}
-					if releasePartsCount > 2 {
-						releaseKubeContext = releaseParts[releasePartsCount-3]
-					}
-					for _, r := range allReleases {
-						if len(releaseNamespace) > 0 && r.Namespace != releaseNamespace {
-							continue
-						}
-						if len(releaseKubeContext) > 0 && r.KubeContext != releaseKubeContext {
-							continue
-						}
-						if r.Name == releaseName {
-							collectNeeds(r, selectedIds, needed, allReleases, includeTransitiveNeeds)
-						}
-					}
-				}
-			}
-		}
-	}
+	return selected, deduplicated, nil
 }
 
 func (a *App) apply(r *Run, c ApplyConfigProvider) (bool, bool, []error) {
@@ -1323,6 +1329,9 @@ Do you really want to apply?
 
 	affectedReleases := state.AffectedReleases{}
 
+	// Traverse DAG of all the releases so that we don't suffer from false-positive missing dependencies
+	st.Releases = selectedAndNeededReleases
+
 	if !interactive || interactive && r.askForConfirmation(confMsg) {
 		r.helm.SetExtraArgs(argparser.GetArgs(c.Args(), r.state)...)
 
@@ -1458,7 +1467,7 @@ Do you really want to delete?
 func (a *App) diff(r *Run, c DiffConfigProvider) (*string, bool, bool, []error) {
 	st := r.state
 
-	selectedReleases, selectedAndNeededReleases, err := a.getSelectedReleases(r, false)
+	selectedReleases, deduplicatedReleases, err := a.getSelectedReleases(r, false)
 	if err != nil {
 		return nil, false, false, []error{err}
 	}
@@ -1477,7 +1486,7 @@ func (a *App) diff(r *Run, c DiffConfigProvider) (*string, bool, bool, []error)
 		SkipDiffOnInstall: c.SkipDiffOnInstall(),
 	}
 
-	st.Releases = selectedAndNeededReleases
+	st.Releases = deduplicatedReleases
 
 	plan, err := st.PlanReleases(state.PlanOptions{Reverse: false, SelectedReleases: selectedReleases, SkipNeeds: c.SkipNeeds(), IncludeNeeds: c.IncludeNeeds(), IncludeTransitiveNeeds: false})
 	if err != nil {
@@ -1553,7 +1562,8 @@ func (a *App) lint(r *Run, c LintConfigProvider) (bool, []error, []error) {
 	if len(toLint) > 0 {
 		_, templateErrs := withDAG(st, helm, a.Logger, state.PlanOptions{SelectedReleases: toLint, Reverse: false, SkipNeeds: true}, a.WrapWithoutSelector(func(subst *state.HelmState, helm helmexec.Interface) []error {
 			opts := &state.LintOpts{
-				Set: c.Set(),
+				Set:         c.Set(),
+				SkipCleanup: c.SkipCleanup(),
 			}
 			lintErrs := subst.LintReleases(helm, c.Values(), args, c.Concurrency(), opts)
 			if len(lintErrs) == 1 {
@@ -1731,7 +1741,7 @@ func (a *App) sync(r *Run, c SyncConfigProvider) (bool, []error) {
 	r.helm.SetExtraArgs(argparser.GetArgs(c.Args(), r.state)...)
 
 	// Traverse DAG of all the releases so that we don't suffer from false-positive missing dependencies
-	st.Releases = toSyncWithNeeds
+	st.Releases = selectedAndNeededReleases
 
 	affectedReleases := state.AffectedReleases{}
 
@@ -1926,6 +1936,7 @@ func (a *App) writeValues(r *Run, c WriteValuesConfigProvider) (bool, []error) {
 		opts := &state.WriteValuesOpts{
 			Set:                c.Set(),
 			OutputFileTemplate: c.OutputFileTemplate(),
+			SkipCleanup:        c.SkipCleanup(),
 		}
 		errs = st.WriteReleasesValues(helm, c.Values(), opts)
 	}
