@@ -98,7 +98,7 @@ func (r *Run) withPreparedCharts(helmfileCommand string, opts state.ChartPrepare
 func (r *Run) Deps(c DepsConfigProvider) []error {
 	r.helm.SetExtraArgs(argparser.GetArgs(c.Args(), r.state)...)
 
-	return r.state.UpdateDeps(r.helm)
+	return r.state.UpdateDeps(r.helm, c.IncludeTransitiveNeeds())
 }
 
 func (r *Run) Repos(c ReposConfigProvider) error {
