@@ -61,6 +61,7 @@ type ReleaseSetSpec struct {
 	Releases            []ReleaseSpec     `yaml:"releases,omitempty"`
 	Selectors           []string          `yaml:"-"`
 	ApiVersions         []string          `yaml:"apiVersions,omitempty"`
+	KubeVersion         string            `yaml:"kubeVersion,omitempty"`
 
 	// Hooks is a list of extension points paired with operations, that are executed in specific points of the lifecycle of releases defined in helmfile
 	Hooks []event.Hook `yaml:"hooks,omitempty"`
@@ -173,6 +174,7 @@ type RepositorySpec struct {
 	Managed         string `yaml:"managed,omitempty"`
 	OCI             bool   `yaml:"oci,omitempty"`
 	PassCredentials string `yaml:"passCredentials,omitempty"`
+	SkipTLSVerify   string `yaml:"skipTLSVerify,omitempty"`
 }
 
 // ReleaseSpec defines the structure of a helm release
@@ -393,7 +395,7 @@ func (st *HelmState) ApplyOverrides(spec *ReleaseSpec) {
 
 type RepoUpdater interface {
 	IsHelm3() bool
-	AddRepo(name, repository, cafile, certfile, keyfile, username, password string, managed string, passCredentials string) error
+	AddRepo(name, repository, cafile, certfile, keyfile, username, password string, managed string, passCredentials string, skipTLSVerify string) error
 	UpdateRepo() error
 	RegistryLogin(name string, username string, password string) error
 }
@@ -412,7 +414,7 @@ func (st *HelmState) SyncRepos(helm RepoUpdater, shouldSkip map[string]bool) ([]
 				err = helm.RegistryLogin(repo.URL, username, password)
 			}
 		} else {
-			err = helm.AddRepo(repo.Name, repo.URL, repo.CaFile, repo.CertFile, repo.KeyFile, repo.Username, repo.Password, repo.Managed, repo.PassCredentials)
+			err = helm.AddRepo(repo.Name, repo.URL, repo.CaFile, repo.CertFile, repo.KeyFile, repo.Username, repo.Password, repo.Managed, repo.PassCredentials, repo.SkipTLSVerify)
 		}
 
 		if err != nil {
@@ -462,7 +464,7 @@ func (st *HelmState) prepareSyncReleases(helm helmexec.Interface, additionalValu
 	}
 
 	releases := []*ReleaseSpec{}
-	for i, _ := range st.Releases {
+	for i := range st.Releases {
 		releases = append(releases, &st.Releases[i])
 	}
 
@@ -764,15 +766,13 @@ func (st *HelmState) SyncReleases(affectedReleases *AffectedReleases, helm helme
 
 	preps, prepErrs := st.prepareSyncReleases(helm, additionalValues, workerLimit, opts)
 
-	defer func() {
-		if opts.SkipCleanup {
-			return
-		}
-
-		for _, p := range preps {
-			st.removeFiles(p.files)
-		}
-	}()
+	if !opts.SkipCleanup {
+		defer func() {
+			for _, p := range preps {
+				st.removeFiles(p.files)
+			}
+		}()
+	}
 
 	if len(prepErrs) > 0 {
 		return prepErrs
@@ -851,11 +851,19 @@ func (st *HelmState) SyncReleases(affectedReleases *AffectedReleases, helm helme
 				}
 
 				if _, err := st.triggerPostsyncEvent(release, relErr, "sync"); err != nil {
-					st.logger.Warnf("warn: %v\n", err)
+					if relErr == nil {
+						relErr = newReleaseFailedError(release, err)
+					} else {
+						st.logger.Warnf("warn: %v\n", err)
+					}
 				}
 
 				if _, err := st.TriggerCleanupEvent(release, "sync"); err != nil {
-					st.logger.Warnf("warn: %v\n", err)
+					if relErr == nil {
+						relErr = newReleaseFailedError(release, err)
+					} else {
+						st.logger.Warnf("warn: %v\n", err)
+					}
 				}
 
 				if relErr == nil {
@@ -1329,13 +1337,9 @@ func (st *HelmState) TemplateReleases(helm helmexec.Interface, outputDir string,
 
 		flags, files, err := st.flagsForTemplate(helm, release, 0)
 
-		defer func() {
-			if opts.SkipCleanup {
-				return
-			}
-
-			st.removeFiles(files)
-		}()
+		if !opts.SkipCleanup {
+			defer st.removeFiles(files)
+		}
 
 		if err != nil {
 			errs = append(errs, err)
@@ -1402,6 +1406,7 @@ func (st *HelmState) TemplateReleases(helm helmexec.Interface, outputDir string,
 type WriteValuesOpts struct {
 	Set                []string
 	OutputFileTemplate string
+	SkipCleanup        bool
 }
 
 type WriteValuesOpt interface{ Apply(*WriteValuesOpts) }
@@ -1431,9 +1436,9 @@ func (st *HelmState) WriteReleasesValues(helm helmexec.Interface, additionalValu
 			return []error{err}
 		}
 
-		defer func() {
-			st.removeFiles(generatedFiles)
-		}()
+		if !opts.SkipCleanup {
+			defer st.removeFiles(generatedFiles)
+		}
 
 		for _, value := range additionalValues {
 			valfile, err := filepath.Abs(value)
@@ -1496,7 +1501,8 @@ func (st *HelmState) WriteReleasesValues(helm helmexec.Interface, additionalValu
 }
 
 type LintOpts struct {
-	Set []string
+	Set         []string
+	SkipCleanup bool
 }
 
 type LintOpt interface{ Apply(*LintOpts) }
@@ -1530,7 +1536,9 @@ func (st *HelmState) LintReleases(helm helmexec.Interface, additionalValues []st
 
 		flags, files, err := st.flagsForLint(helm, &release, 0)
 
-		defer st.removeFiles(files)
+		if !opts.SkipCleanup {
+			defer st.removeFiles(files)
+		}
 
 		if err != nil {
 			errs = append(errs, err)
@@ -1615,7 +1623,7 @@ func (st *HelmState) prepareDiffReleases(helm helmexec.Interface, additionalValu
 	}
 
 	releases := []*ReleaseSpec{}
-	for i, _ := range st.Releases {
+	for i := range st.Releases {
 		if !st.Releases[i].Desired() {
 			continue
 		}
@@ -1780,13 +1788,11 @@ func (st *HelmState) createHelmContextWithWriter(spec *ReleaseSpec, w io.Writer)
 }
 
 type DiffOpts struct {
-	Context int
-	Output  string
-	NoColor bool
-	Set     []string
-
-	SkipCleanup bool
-
+	Context           int
+	Output            string
+	NoColor           bool
+	Set               []string
+	SkipCleanup       bool
 	SkipDiffOnInstall bool
 }
 
@@ -1812,15 +1818,13 @@ func (st *HelmState) DiffReleases(helm helmexec.Interface, additionalValues []st
 
 	preps, prepErrs := st.prepareDiffReleases(helm, additionalValues, workerLimit, detailedExitCode, includeTests, suppressSecrets, showSecrets, opts)
 
-	defer func() {
-		if opts.SkipCleanup {
-			return
-		}
-
-		for _, p := range preps {
-			st.removeFiles(p.files)
-		}
-	}()
+	if !opts.SkipCleanup {
+		defer func() {
+			for _, p := range preps {
+				st.removeFiles(p.files)
+			}
+		}()
+	}
 
 	if len(prepErrs) > 0 {
 		return []ReleaseSpec{}, prepErrs
@@ -1888,8 +1892,11 @@ func (st *HelmState) DiffReleases(helm helmexec.Interface, additionalValues []st
 	)
 
 	for _, p := range preps {
-		if stdout, ok := outputs[ReleaseToID(p.release)]; ok {
+		id := ReleaseToID(p.release)
+		if stdout, ok := outputs[id]; ok {
 			fmt.Print(stdout.String())
+		} else {
+			panic(fmt.Sprintf("missing output for release %s", id))
 		}
 	}
 
@@ -2062,25 +2069,13 @@ func markExcludedReleases(releases []ReleaseSpec, selectors []string, commonLabe
 			}
 		}
 		var conditionMatch bool
-		if len(r.Condition) > 0 {
-			conditionSplit := strings.Split(r.Condition, ".")
-			if len(conditionSplit) != 2 {
-				return nil, fmt.Errorf("Condition value must be in the form 'foo.enabled' where 'foo' can be modified as necessary")
-			}
-			if v, ok := values[conditionSplit[0]]; ok {
-				if v == nil {
-					panic(fmt.Sprintf("environment values field '%s' is nil", conditionSplit[0]))
-				}
-				if v.(map[string]interface{})["enabled"] == true {
-					conditionMatch = true
-				}
-			} else {
-				panic(fmt.Sprintf("environment values does not contain field '%s'", conditionSplit[0]))
-			}
+		conditionMatch, err := ConditionEnabled(r, values)
+		if err != nil {
+			return nil, fmt.Errorf("failed to parse condition in release %s: %w", r.Name, err)
 		}
 		res := Release{
 			ReleaseSpec: r,
-			Filtered:    (len(filters) > 0 && !filterMatch) || (len(r.Condition) > 0 && !conditionMatch),
+			Filtered:    (len(filters) > 0 && !filterMatch) || (!conditionMatch),
 		}
 		filteredReleases = append(filteredReleases, res)
 	}
@@ -2090,6 +2085,29 @@ func markExcludedReleases(releases []ReleaseSpec, selectors []string, commonLabe
 	return filteredReleases, nil
 }
 
+func ConditionEnabled(r ReleaseSpec, values map[string]interface{}) (bool, error) {
+	var conditionMatch bool
+	if len(r.Condition) == 0 {
+		return true, nil
+	}
+	conditionSplit := strings.Split(r.Condition, ".")
+	if len(conditionSplit) != 2 {
+		return false, fmt.Errorf("Condition value must be in the form 'foo.enabled' where 'foo' can be modified as necessary")
+	}
+	if v, ok := values[conditionSplit[0]]; ok {
+		if v == nil {
+			panic(fmt.Sprintf("environment values field '%s' is nil", conditionSplit[0]))
+		}
+		if v.(map[string]interface{})["enabled"] == true {
+			conditionMatch = true
+		}
+	} else {
+		panic(fmt.Sprintf("environment values does not contain field '%s'", conditionSplit[0]))
+	}
+
+	return conditionMatch, nil
+}
+
 func unmarkNeedsAndTransitives(filteredReleases []Release, allReleases []ReleaseSpec) {
 	needsWithTranstives := collectAllNeedsWithTransitives(filteredReleases, allReleases)
 	unmarkReleases(needsWithTranstives, filteredReleases)
@@ -2455,6 +2473,9 @@ func (st *HelmState) flagsForTemplate(helm helmexec.Interface, release *ReleaseS
 	}
 
 	flags = st.appendApiVersionsFlags(flags)
+	if st.KubeVersion != "" {
+		flags = append(flags, "--kube-version", st.KubeVersion)
+	}
 
 	common, files, err := st.namespaceAndValuesFlags(helm, release, workerIndex)
 	if err != nil {
